% Filename: Aarticle.cls
% Author: Andriy Zhugayevych  azh@ukr.net
% Options:  ua/ru  - Ukrainian/Russian language
%           notocs - do not print tableofcontents (the default is print)
%           nohyperref - do not load hyperref

\NeedsTeXFormat{LaTeX2e}[1994/12/01]
\ProvidesClass{Aarticle}[2018/02/04 Article class]
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax
\LoadClass[a4paper]{article}

\newif\if@ua
\newif\if@ru
\newif\if@notocs
\newif\if@nohyperref
\DeclareOption*{}
\DeclareOption{ua}{\@uatrue}
\DeclareOption{ru}{\@rutrue}
\DeclareOption{a4paper}{    \setlength{\textwidth}{185mm}\setlength{\textheight}{260mm}}
\DeclareOption{a5paper}{    \setlength{\textwidth}{125mm}\setlength{\textheight}{180mm}}
\DeclareOption{letterpaper}{\setlength{\textwidth}{190mm}\setlength{\textheight}{240mm}}
\DeclareOption{notocs}{\@notocstrue}
\DeclareOption{nohyperref}{\@nohyperreftrue}
\ExecuteOptions{a4paper} % default paper size
\ProcessOptions\relax

\RequirePackage{ifpdf}

\if@nohyperref\else\ifpdf\RequirePackage[bookmarks=false,pdfstartview={XYZ 0 0 0},hidelinks]{hyperref}\fi\fi

\if@ua
\ifpdf\RequirePackage{cmap}\pdfmapfile{+cm-super-t2a.map}\fi
\RequirePackage[utf8]{inputenc} % old tex-files might use cp1251
% also you might use \usepackage[T1,T2A]{fontenc}
\RequirePackage[ukrainian]{babel}
\fi

\if@ru
\ifpdf\RequirePackage{cmap}\pdfmapfile{+cm-super-t2a.map}\fi
\RequirePackage[utf8]{inputenc}
\RequirePackage[russian]{babel}
\fi

\RequirePackage{Amath}
\RequirePackage[capitalize]{cleveref}
\RequirePackage{graphicx}

% Page layout
\setlength{\topmargin}{-20mm}
\setlength{\oddsidemargin}{-10mm}
\setlength{\evensidemargin}{-10mm}

% New entries in title
\def\affiliation#1{\gdef\@affiliation{#1}}
\let\@affiliation\@empty


% Make title
\renewcommand{\maketitle}{
\thispagestyle{empty}
\noindent
%\hbox to \textwidth {\fbox{\sffamily\large\bfseries\@preprint}\hfil}
\begin{center}
{\LARGE\bfseries \@title \par}
\vskip 1ex
{\large \@author \par}
\vskip 0.25ex
{\itshape \@affiliation \par}
\vskip 0.5ex
{\large \@date \par}
\end{center}
\if@notocs\else\par{\small\@starttoc{toc}}\fi}


% Referencing - depreciated - use cleveref package
%\newcommand{\sref}[1]{Section~\ref{#1}}
%\newcommand{\fref}[1]{Figure~\ref{#1}}
%\newcommand{\tref}[1]{Table~\ref{#1}}
