% Filename: Abook.cls
% Author: Andriy Zhugayevych  azh@ukr.net
% Options:  ua/ru  - Ukrainian/Russian language
%           notocs - do not print tableofcontents (the default is print)
%           bibaschap - treat biblio and appendix as chapter (the default is as section)

\NeedsTeXFormat{LaTeX2e}[1994/12/01]
\ProvidesClass{Abook}[2010/08/01 Book class]
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{book}}
\ProcessOptions\relax
\LoadClass[a4paper]{book}

\newif\if@ua
\newif\if@ru
\newif\if@notocs
\newif\if@bibaschap
\DeclareOption*{}
\DeclareOption{ua}{\@uatrue}
\DeclareOption{ru}{\@rutrue}
\DeclareOption{a4paper}{    \setlength{\textwidth}{185mm}\setlength{\textheight}{260mm}}
\DeclareOption{a5paper}{    \setlength{\textwidth}{125mm}\setlength{\textheight}{180mm}}
\DeclareOption{letterpaper}{\setlength{\textwidth}{190mm}\setlength{\textheight}{240mm}}
\DeclareOption{notocs}{\@notocstrue}
\DeclareOption{bibaschap}{\@bibaschaptrue}
\ExecuteOptions{a4paper} % default paper size
\ProcessOptions\relax

\RequirePackage{ifpdf}

\if@ua
\ifpdf\RequirePackage{cmap}\pdfmapfile{+cm-super-t2a.map}\fi
\RequirePackage[utf8]{inputenc} % old tex-files might use cp1251
% also you might use \usepackage[T1,T2A]{fontenc}
\RequirePackage[ukrainian]{babel}
\fi

\if@ru
\ifpdf\RequirePackage{cmap}\pdfmapfile{+cm-super-t2a.map}\fi
\RequirePackage[utf8]{inputenc}
\RequirePackage[russian]{babel}
\fi

\RequirePackage{Amath}


% Page layout
\setlength{\topmargin}{-20mm}
\setlength{\oddsidemargin}{-10mm}
\setlength{\evensidemargin}{-10mm}


% Title and TOCs
\renewcommand{\maketitle}{
\thispagestyle{empty}
\begin{center}
{\LARGE\bfseries\@title\par}
\vskip 1ex
{\large\@author\par}
\vskip 0.5ex
{\normalsize\slshape\@date}
\end{center}
\if@notocs\else\par{\small\@starttoc{toc}}\fi}


% Referencing
\newcommand{\sref}[1]{Section~\ref{#1}}
\newcommand{\fref}[1]{Figure~\ref{#1}}
\newcommand{\tref}[1]{Table~\ref{#1}}


% appendix
\if@bibaschap
\else
\renewcommand\appendix{\par\bigskip
 \section*{\appendixname}%
 \addcontentsline{toc}{section}{\appendixname}%
 \setcounter{section}{0}%
 \gdef\thesection{\@Alph\c@section}}%
 \gdef\theequation{\thesection.\@arabic\c@equation}
\fi


% thebibliography
\if@bibaschap
\else
\newcommand{\refname}{References}
\renewenvironment{thebibliography}[1]{%
  \bigskip
  \section*{\refname}%
  \addcontentsline{toc}{section}{\refname}%
  \@mkboth{\refname}{\refname}%
  \list{\@biblabel{\@arabic\c@enumiv}}{%
    \settowidth\labelwidth{\@biblabel{#1}}%
    \leftmargin\labelwidth
    \advance\leftmargin\labelsep
    \@openbib@code
    \usecounter{enumiv}%
    \let\p@enumiv\@empty
    \renewcommand\theenumiv{\@arabic\c@enumiv}}%
\sloppy
\clubpenalty4000
\@clubpenalty \clubpenalty
\widowpenalty4000%
\sfcode`\.\@m}
{\def\@noitemerr{\@latex@warning{Empty `thebibliography' environment}}\endlist}
\fi


% Overfull warnings
\hfuzz3pt  % Don't bother to report overfull h-boxes < 3pt
\vfuzz3pt  % Don't bother to report overfull v-boxes < 3pt
